@@ -5,5 +5,9 @@ Init file for the SpatialCluster library.
 from SpatialCluster.core import DMoN_Clustering, visualize_map_sample
 from SpatialCluster.methods.GMM import GMM_Clustering
 
-version_info = (0, 0, 16)
-__version__ = ".".join([str(x) for x in version_info])
\ No newline at end of file
+version_info = (0, 0, 19)
+__version__ = ".".join([str(x) for x in version_info])
+
+__all__ = [
+    "preprocess"
+]
\ No newline at end of file
